@@ -6,17 +6,19 @@ from numpy import linalg as LG
 pi = math.pi
 
 # Our general class will read a Current file and a Voltages file to output a Dirichlet to Neumann map.
-# It basis itself on:
+# Variables: 
 # r - radius of body (assumed symmetrical for now) 
 # AE -  area of the electrodes
 # L - Number of Electrodes
 class read_data:
-    def __init__(self, str_Object, r, AE, L):
+
+    # The Current and Voltage file should be in the format: L-1 lines with values for the L electrodes.
+    def __init__(self, Current, Voltage, r, AE, L):
         self.L = L
         self.r = r
         self.AE = AE
-        self.Current = np.loadtxt("EIT_Data/"+str_Object+"Current.txt").transpose() # Matrix L x L-1
-        self.Voltage = np.loadtxt("EIT_Data/"+str_Object+"Voltage.txt").transpose() # Matrix L x L-1
+        self.Current = Current.transpose() # Matrix L x L-1
+        self.Voltage = Voltage.transpose() # Matrix L x L-1
         self.DNmap = np.zeros((L-1, L-1))
         self.load()
         
